@@ -83,14 +83,14 @@ struct SynapticsHwInfo;
 struct CommData;
 
 struct SynapticsProtocolOperations {
-    void (*DeviceOnHook)(LocalDevicePtr local, struct _SynapticsParameters *para);
-    void (*DeviceOffHook)(LocalDevicePtr local);
-    Bool (*QueryHardware)(LocalDevicePtr local);
-    Bool (*ReadHwState)(LocalDevicePtr local,
+    void (*DeviceOnHook)(InputInfoPtr pInfo, struct _SynapticsParameters *para);
+    void (*DeviceOffHook)(InputInfoPtr pInfo);
+    Bool (*QueryHardware)(InputInfoPtr pInfo);
+    Bool (*ReadHwState)(InputInfoPtr pInfo,
 			struct SynapticsProtocolOperations *proto_ops,
 			struct CommData *comm, struct SynapticsHwState *hwRet);
-    Bool (*AutoDevProbe)(LocalDevicePtr local);
-    void (*ReadDevDimensions)(LocalDevicePtr local);
+    Bool (*AutoDevProbe)(InputInfoPtr pInfo);
+    void (*ReadDevDimensions)(InputInfoPtr pInfo);
 };
 
 extern struct SynapticsProtocolOperations psaux_proto_operations;
